from django.test import TestCase, override_settings
from cent.core import generate_channel_sign
from .base import InstantBaseTest
from ..producers import _get_channel
from ..conf import PUBLIC_CHANNEL, SITE_SLUG, PUBLIC_CHANNELS
from ..utils import signed_response, _get_public_channel, _ensure_channel_is_private, \
    _check_chanconf, channels_for_role


class InstantTestUtils(InstantBaseTest):

    def test_get_public_channel(self):
        chan = _get_public_channel()
        self.assertEqual(chan, PUBLIC_CHANNEL)

    def test_signed_response(self):
        client = "client"
        chan = "test_chan"
        signature = generate_channel_sign(self.key, client, chan, info="")
        resp = signed_response(chan, client)
        self.assertEqual(resp, {"sign": signature})

    def test__ensure_channel_is_private(self):
        priv = _ensure_channel_is_private("$chan")
        self.assertEqual(priv, "$chan")
        priv = _ensure_channel_is_private("chan")
        self.assertEqual(priv, "$chan")

    def test_check_chanconf(self):
        """
        # settings:
        INSTANT_PUBLIC_CHANNELS=[
           ['test_site_public1'],
           ['test_site_public2'],
        ],
        """
        conf = _check_chanconf(PUBLIC_CHANNELS[0], False)
        res = dict(slug="test_site_public1", path=None)
        self.assertEqual(conf, res)

    def test_channels_for_role(self):
        """
        # settings:
        INSTANT_SUPERUSER_CHANNELS=[
            ["$test_site_admin1", ["/a/path", "/another/path"]],
            ['$test_site_admin2']
        ],
        INSTANT_STAFF_CHANNELS=[
            ["$test_site_staff1", ["/a/path"]],
            ['$test_site_staff2'],
        ],
        INSTANT_USERS_CHANNELS=[
            ['$test_site_users1'],
        ],
        INSTANT_PUBLIC_CHANNELS=[
            ['test_site_public1'],
            ['test_site_public2'],
        ],
        """
        chans, chans_names = channels_for_role("public")
        self.assertEqual(
            chans_names, [
                "test_site_public", "test_site_public1", "test_site_public2"])
        expected_chans = [
            dict(slug=PUBLIC_CHANNEL, path=None),
            dict(slug="test_site_public1", path=None),
            dict(slug="test_site_public2", path=None)
        ]
        self.assertEqual(chans, expected_chans)

        chans, chans_names = channels_for_role("users")
        self.assertEqual(chans_names, ["$test_site_users1"])
        expected_chans = [
            dict(slug="$test_site_users1", path=None)
        ]
        self.assertEqual(chans, expected_chans)

        chans, chans_names = channels_for_role("staff")
        self.assertEqual(
            chans_names, [
                "$test_site_staff1", "$test_site_staff2"])
        expected_chans = [
            dict(slug="$test_site_staff1", path=["/a/path"]),
            dict(slug="$test_site_staff2", path=None)
        ]
        self.assertEqual(chans, expected_chans)

        chans, chans_names = channels_for_role("superuser")
        self.assertEqual(
            chans_names, [
                "$test_site_admin1", "$test_site_admin2"])
        expected_chans = [
            dict(slug="$test_site_admin1", path=["/a/path", "/another/path"]),
            dict(slug="$test_site_admin2", path=None)
        ]
        self.assertEqual(chans, expected_chans)

    """
    @override_settings(INSTANT_ENABLE_PUBLIC_CHANNEL=False)
    def test_channels_for_role_no_defaults(self):
        # TOFIX
        chans, chans_names = channels_for_role("public")
        self.assertEqual(
            chans_names, [
                "test_site_public1", "test_site_public2"])
        expected_chans = [
            dict(slug="test_site_public1", path=None),
            dict(slug="test_site_public2", path=None)
        ]
        self.assertEqual(chans, expected_chans)"""



import time
from django.test import TestCase
from cent.core import generate_token
from .base import InstantBaseTest
from ..templatetags.instant_tags import get_centrifugo_url, debug_mode, get_timestamp, \
    mq_generate_token, public_channel_is_on, get_public_channel, is_users_channel, \
    get_users_channel, is_staff_channel, get_staff_channel, is_superuser_channel, \
    get_superuser_channel, _get_channels_for_role, get_all_channels, \
    get_channels_for_role, get_handlers_url, get_apps, is_in_apps, get_default_channels, \
    exclude_chans, num_excluded_chans


class InstantTestTemplatetags(InstantBaseTest):

    def test_get_centrifugo_url(self):
        url = get_centrifugo_url()
        html = self.render_template(
            '{% load instant_tags %}'
            '{% get_centrifugo_url %}'
        )
        self.assertEqual(html, "http://localhost:8001")

    def test_debug_mode(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% debug_mode %}'
        )
        self.assertEqual(html, "false")

    def test_get_timestamp(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% get_timestamp %}'
        )
        ts = str(int(time.time()))
        self.assertEqual(html, ts)

    """
    # TOFIX

    def test_public_channel_is_on(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% public_channel_is_on %}'
        )
        self.assertEqual(html, True)
    """

    def test_get_timestamp(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% get_timestamp %}'
        )
        ts = str(int(time.time()))
        self.assertEqual(html, ts)

    def test_mq_generate_token(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% mq_generate_token "username" "1529666693" %}'
        )
        token = generate_token(self.key, "username", "1529666693")
        self.assertEqual(html, token)

    def test_is_users_channel(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% is_users_channel %}'
        )
        uc = "False"
        self.assertEqual(html, uc)

    def test_get_users_channel(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% get_users_channel %}'
        )
        uc = '$test_site_users'
        self.assertEqual(html, uc)

    def test_is_staff_channel(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% is_staff_channel %}'
        )
        uc = "False"
        self.assertEqual(html, uc)

    def test_get_staff_channel(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% get_staff_channel %}'
        )
        uc = "$test_site_staff"
        self.assertEqual(html, uc)

    def test_is_superuser_channel(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% is_superuser_channel %}'
        )
        uc = "False"
        self.assertEqual(html, uc)

    def test_get_superuser_channel(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% get_superuser_channel %}'
        )
        uc = "$test_site_admin"
        self.assertEqual(html, uc)

    """

    # TOFIX

    def test_get_all_channels(self):
        html = self.render_template(
            '{% load instant_tags %}'
            '{% get_all_channels %}'
        )
        uc = []
        self.assertEqual(html, uc)

    # TODO : remove useless code

    public_channel_is_on
    get_public_channel

    """



from django.test import TestCase
from django.conf import settings
from django.template import Context, Template


class InstantBaseTest(TestCase):

    def setUp(self):
        self.maxDiff = None
        self.key = getattr(settings, "CENTRIFUGO_SECRET_KEY")

    def debug(self, msg):
        print("\n----------------------------------------------")
        print(msg)
        print("----------------------------------------------")

    def render_template(self, string, context=None):
        context = context or {}
        context = Context(context)
        return Template(string).render(context)



#!/usr/bin/env python3
import glob
import os
import sys

import django
from django.conf import settings
from django.core.management import execute_from_command_line


BASE_DIR = os.path.abspath(os.path.dirname(__file__))
sys.path.append(os.path.abspath(os.path.join(BASE_DIR, '..')))

# Unfortunately, apps can not be installed via ``modify_settings``
# decorator, because it would miss the database setup.
CUSTOM_INSTALLED_APPS = (
    'django.contrib.admin',
    "instant",
)

ALWAYS_INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
)

ALWAYS_MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

settings.configure(
    BASE_DIR=BASE_DIR,
    SECRET_KEY="django_tests_secret_key",
    DEBUG=False,
    TEMPLATE_DEBUG=False,
    ALLOWED_HOSTS=[],
    INSTALLED_APPS=ALWAYS_INSTALLED_APPS + CUSTOM_INSTALLED_APPS,
    MIDDLEWARE_CLASSES=ALWAYS_MIDDLEWARE_CLASSES,
    ROOT_URLCONF='tests.urls',
    DATABASES={
        'default': {
            'ENGINE': 'django.db.backends.sqlite3',
            'NAME': 'test_db',
        }
    },
    LANGUAGE_CODE='en-us',
    TIME_ZONE='UTC',
    USE_I18N=True,
    USE_L10N=True,
    USE_TZ=True,
    STATIC_URL='/static/',
    # Use a fast hasher to speed up tests.
    PASSWORD_HASHERS=(
        'django.contrib.auth.hashers.MD5PasswordHasher',
    ),
    FIXTURE_DIRS=glob.glob(BASE_DIR + '/' + '*/fixtures/'),

    TEMPLATES=[
        {
            'BACKEND': 'django.template.backends.django.DjangoTemplates',
            'DIRS': ['templates'],
            'OPTIONS': {
                'context_processors': [
                    'django.template.context_processors.debug',
                    'django.template.context_processors.request',
                    'django.contrib.auth.context_processors.auth',
                    'django.contrib.messages.context_processors.messages',
                    # !extra_context_processors!
                ],
                'debug': True,
                'loaders': [
                    'django.template.loaders.filesystem.Loader',
                    'django.template.loaders.app_directories.Loader',
                ],
            },
        },
    ],

    CENTRIFUGO_SECRET_KEY="secret_key",
    SITE_SLUG="test_site",
    SITE_NAME="Test site",

    INSTANT_SUPERUSER_CHANNELS=[
        ["$test_site_admin1", ["/a/path", "/another/path"]],
        ['$test_site_admin2']
    ],
    INSTANT_STAFF_CHANNELS=[
        ["$test_site_staff1", ["/a/path"]],
        ['$test_site_staff2'],
    ],
    INSTANT_USERS_CHANNELS=[
        ['$test_site_users1'],
    ],
    INSTANT_PUBLIC_CHANNELS=[
        ['test_site_public1'],
        ['test_site_public2'],
    ],
)

django.setup()
args = [sys.argv[0], 'test']

# Current module (``tests``) and its submodules.
test_cases = '.'

# Allow accessing test options from the command line.
offset = 1
try:
    sys.argv[1]
except IndexError:
    pass
else:
    option = sys.argv[1].startswith('-')
    if not option:
        test_cases = sys.argv[1]
        offset = 2

args.append(test_cases)
# ``verbosity`` can be overwritten from command line.
args.append('--verbosity=2')
args.extend(sys.argv[offset:])

execute_from_command_line(args)



from django.test import TestCase
from .base import InstantBaseTest
from ..producers import _get_channel, publish
from ..conf import PUBLIC_CHANNEL, SITE_SLUG


class InstantTestProducers(InstantBaseTest):

    def test_get_channel(self):
        chan = _get_channel(None, None)
        self.assertEqual(chan, PUBLIC_CHANNEL)
        chan = _get_channel(None, "users")
        self.assertEqual(chan, "$" + SITE_SLUG + '_users')
        chan = _get_channel(None, "superuser")
        self.assertEqual(chan, "$" + SITE_SLUG + '_admin')
        chan = _get_channel(None, "staff")
        self.assertEqual(chan, "$" + SITE_SLUG + '_staff')
        chan = _get_channel("chan", "users")
        self.assertEqual(chan, "chan")

    """
    # TOFIX
    def test_producers_settings(self):
        err = publish("Test message")
        self.assertEqual(err, None)
        with self.settings(INSTANT_BROADCAST_WITH="go"):
            from django.conf import settings
            from ..conf import BROADCAST_WITH
            self.debug(BROADCAST_WITH)
            self.debug(settings.INSTANT_BROADCAST_WITH)
            err = publish("Test message")
            self.assertEqual(err, None)
    """